# Copyright (c) 2008, 2009 David Sugar, Tycho Softworks.
# This file is free software; as a special exception the author gives
# unlimited permission to copy and/or distribute it, with or without
# modifications, as long as this notice is preserved.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY, to the extent permitted by law; without
# even the implied warranty of MERCHANTABILITY or FITNESS FOR A
# PARTICULAR PURPOSE.

Name: ucommon
Summary: Portable C++ framework for threads and sockets
Version: 3.2.1
Release: 0%{?dist}
License: LGPLv3+
URL: http://www.gnu.org/software/commoncpp
Source0: http://www.gnutelephony.org/dist/tarballs/ucommon-%{version}.tar.gz
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root
BuildRequires: doxygen graphviz-gd openssl-devel
Group: System Environment/Libraries
Summary: Runtime library for portable C++ threading and sockets

%description
GNU uCommon C++ is a lightweight library to facilitate using C++ design
patterns even for very deeply embedded applications, such as for systems using
uClibc along with POSIX threading support. For this reason, uCommon disables
language features that consume memory or introduce runtime overhead. UCommon
introduces some design patterns from Objective-C, such as reference counted
objects, memory pools, and smart pointers. UCommon introduces some new concepts
for handling of thread locking and synchronization.

%package secure
Requires: %{name} = %{version}-%{release}
Requires: openssl
Group: System Environment/Libraries
Summary: ucommon framework for secure sockets and cryptography

%package script
Requires: %{name} = %{version}-%{release}
Group: System Environment/Libraries
Summary: uCommon framework for script extensible applications

%package audio
Requires: %{name} = %{version}-%{release}
Group: System Environment/Libraries
Summary: uCommon framework for telephonic audio support

%package audio-tools
Requires: %{name} = %{version}-%{release}
Requires: %{name}-audio = %{version}-%{release}
Group: Applications/Multimedia
Summary: Telephonic audio file manipulation utilities

%package devel
Requires: %{name} = %{version}-%{release}
Requires: %{name}-script = %{version}-%{release}
Requires: %{name}-audio = %{version}-%{release}
Requires: %{name}-audio-tools = %{version}-%{release}
Requires: pkgconfig
Group: Development/Libraries
Summary: Headers for building uCommon applications

%package doc
Group: Documentation
Summary: Generated class documentation for uCommon

%description secure
The GNU uCommon C++ secure sockets and cryptography library offers thread-safe
ssl sockets for building clients and servers.  The crytographic library also
provides for random number generation, digest computation, and ciphering.

%description script
GNU uCommon C++ script is a highly specialized embedded scripting engine and
virtual execution environment for creating script "extensible" applications.
This system is a C++ class library which allows one to derive application
specific dialects of the core language as needed through subclassing.

%description audio
The GNU uCommon C++ telephonic audio library covers a range of functionality
including tone generation and detection, streaming and transcoding of encoded
audio frames, accessing of audio files on disk, and phrasebook management.

%description audio-tools
This is a collection of command line tools to manage telephonic audio files and
phrasebook libraries built from the ucommon telephonic audio library.  These
utilities may also be required to build packages which use sampled audio
libraries and phrasebooks.

%description devel
This package provides header and support files needed for building 
applications that use the uCommon library.

%description doc
Generated class documentation for GNU uCommon library from header files, 
html browsable.

%prep
%setup -q
%build

%configure --disable-static
%{__make} %{?_smp_mflags}
%{__rm} -rf doc/html
%{__make} doxy

%install
%{__rm} -rf %{buildroot}
%{__make} DESTDIR=%{buildroot} INSTALL="install -p" install
%{__chmod} 0755 %{buildroot}%{_bindir}/ucommon-config
%{__rm} %{buildroot}%{_libdir}/*.la

%clean
%{__rm} -rf %{buildroot}

%files 
%defattr(-,root,root,-)
%doc AUTHORS README COPYING COPYING.LESSER NEWS SUPPORT ChangeLog
%{_libdir}/libucommon.so.*

%files secure
%defattr(-,root,root,-)
%{_libdir}/libuccsecure.so.*

%files script
%defattr(-,root,root,-)
%{_libdir}/libuccscript.so.*

%files audio
%defattr(-,root,root,-)
%{_libdir}/libuccaudio.so.*

%files audio-tools
%defattr(-,root,root,-)
%{_bindir}/audiotool
%{_mandir}/man1/audiotool.*

%files devel
%defattr(-,root,root,-)
%{_libdir}/*.so
%{_includedir}/ucommon/
%{_libdir}/pkgconfig/*.pc
%{_bindir}/ucommon-config
%{_mandir}/man1/ucommon-config.*

%files doc
%defattr(-,root,root,-)
%doc doc/html/*

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%changelog
* Sun Jul 11 2010 - David Sugar <dyfet@gnutelephony.org> - 3.2.1-0
- uuid generation support and further shell parsing features.

* Sat Jul 03 2010 - David Sugar <dyfet@gnutelephony.org> - 3.2.0-0
- extensive fixing in shell class and introduction of piping.

* Sat Jun 26 2010 - David Sugar <dyfet@gnutelephony.org> - 3.1.2-0
- fixed clearing of key data when secure objects are released.
- fixed and updated shell parsing class.
- extended secure api so we can also use gnutls, maybe later nss.

* Tue Jun 22 2010 - David Sugar <dyfet@gnutelephony.org> - 3.1.0-0
- new ucommon crytographic library added.

* Sun Jun 20 2010 - David Sugar <dyfet@gnutelephony.org> - 3.0.6-0
- some further abi extension of the socket class.

* Mon Jun 14 2010 - David Sugar <dyfet@gnutelephony.org> - 3.0.5-0
- some abi conflict issues with libc macros on some targets.

* Fri Jun 11 2010 - David Sugar <dyfet@gnutelephony.org> - 3.0.4-0
- further revision on the tcp buffering api.

* Fri Jun 11 2010 - David Sugar <dyfet@gnutelephony.org> - 3.0.3-2
- critical fix for reusable objects
- new core full duplex buffered io class, tcp and file buffering
- standardized hostname and service address resolver operations
- atomic operations introduced

* Sun Jun 06 2010 - David Sugar <dyfet@gnutelephony.org> - 3.0.1-0
- threaded queue management and reuse templates and related bugs fixed.

* Fri Jun 04 2010 - David Sugar <dyfet@gnutelephony.org> - 3.0.0-0
- merged ccscript and ccaudio with ucommon to create single framework.

* Tue May 18 2010 - David Sugar <dyfet@gnutelephony.org> - 2.1.4-0
- object containers, unicode support, and datetime api enhanced.

* Sun May 02 2010 - David Sugar <dyfet@gnutelephony.org> - 2.1.3-0
- critical fix for ieq string function.
- new unicode string class and api introduced.

* Sun Apr 25 2010 - David Sugar <dyfet@gnutelephony.org> - 2.1.2-0
- improved portability and api changes for datetime.

* Sun Apr 11 2010 - David Sugar <dyfet@gnutelephony.org> - 2.1.1-0
- new abi release

* Fri Dec 18 2009 - David Sugar <dyfet@gnutelephony.org> - 2.0.7-1
- fixed install script handling upstream and fixed pedantic gcc 4.4 issues.

* Sun Jul 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.0.5-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Tue May 05 2009 - David Sugar <dyfet@gnutelephony.org> - 2.0.5-4
- removed static libraries, fixed other build issues (#498736)

* Sun May 03 2009 - David Sugar <dyfet@gnutelephony.org> - 2.0.5-3
- spec file further revised for redhat/fedora (#498736)

